==> nas_1.5.orig.tar.gz: nas-1.5/lib/audio/SetClsDwnMd.c <==
/*
 * Copyright 1993 Network Computing Devices, Inc.
 * 
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name Network Computing Devices, Inc. not be
 * used in advertising or publicity pertaining to distribution of this
 * software without specific, written prior permission.
 * 
 * THIS SOFTWARE IS PROVIDED 'AS-IS'.  NETWORK COMPUTING DEVICES, INC.,
 * DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING WITHOUT
 * LIMITATION ALL IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NONINFRINGEMENT.  IN NO EVENT SHALL NETWORK
 * COMPUTING DEVICES, INC., BE LIABLE FOR ANY DAMAGES WHATSOEVER, INCLUDING
 * SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOSS OF USE, DATA,
 * OR PROFITS, EVEN IF ADVISED OF THE POSSIBILITY THEREOF, AND REGARDLESS OF
 * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 * $NCDId: @(#)SetClsDwnMd.c,v 1.1 1993/12/28 23:31:20 greg Exp $
 */

#include "Alibint.h"

void
AuSetCloseDownMode(aud, mode, ret_status)
AuServer       *aud;
int             mode;
AuStatus       *ret_status;
{
    register auSetCloseDownModeReq *req;

    if (ret_status)
	*ret_status = AuSuccess;

    _AuLockServer();
    _AuGetReq(SetCloseDownMode, req, aud);

    req->mode = mode;

    (void) _AuIfRoundTrip(aud, ret_status);

    _AuUnlockServer();
    _AuSyncHandle(aud);
}

==> nas_1.7.orig.tar.gz: nas-1.7/lib/audio/SetClsDwnMd.c <==
/*
 * Copyright 1993 Network Computing Devices, Inc.
 * 
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name Network Computing Devices, Inc. not be
 * used in advertising or publicity pertaining to distribution of this
 * software without specific, written prior permission.
 * 
 * THIS SOFTWARE IS PROVIDED 'AS-IS'.  NETWORK COMPUTING DEVICES, INC.,
 * DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING WITHOUT
 * LIMITATION ALL IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NONINFRINGEMENT.  IN NO EVENT SHALL NETWORK
 * COMPUTING DEVICES, INC., BE LIABLE FOR ANY DAMAGES WHATSOEVER, INCLUDING
 * SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOSS OF USE, DATA,
 * OR PROFITS, EVEN IF ADVISED OF THE POSSIBILITY THEREOF, AND REGARDLESS OF
 * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 * $NCDId: @(#)SetClsDwnMd.c,v 1.1 1993/12/28 23:31:20 greg Exp $
 */

#include "Alibint.h"

void
AuSetCloseDownMode(
                   AuServer       *aud,
                   int             mode,
                   AuStatus       *ret_status
                   )
{
    register auSetCloseDownModeReq *req;

    if (ret_status)
	*ret_status = AuSuccess;

    _AuLockServer();
    _AuGetReq(SetCloseDownMode, req, aud);

    req->mode = mode;

    (void) _AuIfRoundTrip(aud, ret_status);

    _AuUnlockServer();
    _AuSyncHandle(aud);
}
